@@ -28,10 +28,36 @@
 */
 /*******************************************************************************/
 #include "weather-portrait.h"
-#if defined OS2009
-    #include <mce/dbus-names.h>
-    #include <mce/mode-names.h>
+#if defined OS2009 
+#include <mce/dbus-names.h>
+#include <mce/mode-names.h>
 /*******************************************************************************/
+DBusHandlerResult
+get_mce_signal_cb_popup(DBusConnection *conn, DBusMessage *msg, gpointer data){
+
+    DBusMessageIter iter;
+    const char *mode_name = NULL;
+    
+    if (dbus_message_is_signal(msg, MCE_SIGNAL_IF, MCE_DEVICE_ORIENTATION_SIG)){
+        if (dbus_message_iter_init(msg, &iter)){
+            dbus_message_iter_get_basic(&iter, &mode_name);
+            fprintf(stderr,"New status %s\n",mode_name);
+
+            if (!strcmp(mode_name, "landscape") && app->popup_portrait_position && data){
+               init_landscape(data);  
+               app->popup_portrait_position = FALSE;
+            }else
+                if (!strcmp(mode_name, "portrait") && !app->popup_portrait_position && data){
+                    init_portrait(data);
+                    app->popup_portrait_position = TRUE;
+                }
+        }else
+            fprintf(stderr,"message did not have argument");
+    }
+
+    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
+}
+
 DBusHandlerResult
 get_mce_signal_cb(DBusConnection *conn, DBusMessage *msg, gpointer data){
 
@@ -43,11 +69,14 @@ get_mce_signal_cb(DBusConnection *conn, DBusMessage *msg, gpointer data){
             dbus_message_iter_get_basic(&iter, &mode_name);
             fprintf(stderr,"New status %s\n",mode_name);
 
-            if (!strcmp(mode_name, "landscape") && app->portrait_position)
+            if (!strcmp(mode_name, "landscape") && app->portrait_position){
                init_landscape(app->main_view);
-            else
-                if (!strcmp(mode_name, "portrait") && !app->portrait_position )
+               app->portrait_position = FALSE;
+            } else
+                if (!strcmp(mode_name, "portrait") && !app->portrait_position){
                     init_portrait(app->main_view);
+                    app->portrait_position = TRUE;
+               }
         }else
             fprintf(stderr,"message did not have argument");
     }
@@ -69,7 +98,6 @@ init_portrait(GtkWidget *win){
   gtk_widget_realize(win);
   set_portrait(win, "_HILDON_PORTRAIT_MODE_SUPPORT", 1);
   set_portrait(win, "_HILDON_PORTRAIT_MODE_REQUEST", 1);
-  app->portrait_position = TRUE;
 }
 /*******************************************************************************/
 void 
@@ -79,7 +107,6 @@ init_landscape(GtkWidget *win){
 
   set_portrait(win, "_HILDON_PORTRAIT_MODE_SUPPORT", 0);
   set_portrait(win, "_HILDON_PORTRAIT_MODE_REQUEST", 0);
-  app->portrait_position = FALSE;
 }
 /*******************************************************************************/
 void
